Edit: So I just ran the author's (alength (long-array 5)) (with the indirection to foil type inference) and got 10µs mean execution time in criterium. By contrast here's some roughly equivalent python:
In [5]: a = array.array('l', [5])
In [6]: timeit len(a)
32.9 ns ± 0.105 ns per loop (mean ± std. dev. of 7 runs, 10000000 loops each)
More or less exactly the same with a plain python list. So clojure's type specialized function manages to be 300 times slower than the generic version in freaking *python*. In fairness "count" is better if still terrible (4x slower than python).